@@ -1,4 +1,4 @@
-/* $OpenBSD: dgst.c,v 1.18 2019/08/30 12:32:14 inoguchi Exp $ */
+/* $OpenBSD: dgst.c,v 1.20 2022/11/11 17:07:38 joshua Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -302,9 +302,6 @@ list_md_fn(const EVP_MD * m, const char *from, const char *to, void *arg)
 	/* Skip shortnames */
 	if (strcmp(from, mname))
 		return;
-	/* Skip clones */
-	if (EVP_MD_flags(m) & EVP_MD_FLAG_PKEY_DIGEST)
-		return;
 	if (strchr(mname, ' '))
 		mname = EVP_MD_name(m);
 	BIO_printf(arg, " -%-17s To use the %s message digest algorithm\n",
@@ -341,11 +338,9 @@ dgst_main(int argc, char **argv)
 	int siglen = 0;
 	char *passin = NULL;
 
-	if (single_execution) {
-		if (pledge("stdio cpath wpath rpath tty", NULL) == -1) {
-			perror("pledge");
-			exit(1);
-		}
+	if (pledge("stdio cpath wpath rpath tty", NULL) == -1) {
+		perror("pledge");
+		exit(1);
 	}
 
 	if ((buf = malloc(BUFSIZE)) == NULL) {
