@@ -1,4 +1,4 @@
-/* $OpenBSD: bn_asm.c,v 1.14 2015/02/25 15:39:49 bcook Exp $ */
+/* $OpenBSD: bn_asm.c,v 1.17 2022/11/30 01:47:19 jsing Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -56,17 +56,12 @@
  * [including the GNU Public Licence.]
  */
 
-#ifndef BN_DEBUG
-# undef NDEBUG /* avoid conflicting definitions */
-# define NDEBUG
-#endif
-
 #include <assert.h>
 #include <stdio.h>
 
 #include <openssl/opensslconf.h>
 
-#include "bn_lcl.h"
+#include "bn_local.h"
 
 #if defined(BN_LLONG) || defined(BN_UMULT_HIGH)
 
@@ -989,8 +984,7 @@ enter:
 	}
 	memcpy(rp, tp, num * sizeof(BN_ULONG));
 out:
-	explicit_bzero(tp, (num + 2) * sizeof(BN_ULONG));
-	free(tp);
+	freezero(tp, (num + 2) * sizeof(BN_ULONG));
 	return 1;
 }
 #else
@@ -1081,8 +1075,7 @@ bn_mul_mont(BN_ULONG *rp, const BN_ULONG *ap, const BN_ULONG *bp,
 	}
 	memcpy(rp, tp, num * sizeof(BN_ULONG));
 out:
-	explicit_bzero(tp, (num + 2) * sizeof(BN_ULONG));
-	free(tp);
+	freezero(tp, (num + 2) * sizeof(BN_ULONG));
 	return 1;
 }
 #else
