@@ -1,4 +1,4 @@
-/* $OpenBSD: bn_ctx.c,v 1.15 2017/01/29 17:49:22 beck Exp $ */
+/* $OpenBSD: bn_ctx.c,v 1.19 2022/11/30 01:47:19 jsing Exp $ */
 /* Written by Ulf Moeller for the OpenSSL project. */
 /* ====================================================================
  * Copyright (c) 1998-2004 The OpenSSL Project.  All rights reserved.
@@ -54,12 +54,6 @@
  *
  */
 
-#if !defined(BN_CTX_DEBUG) && !defined(BN_DEBUG)
-#ifndef NDEBUG
-#define NDEBUG
-#endif
-#endif
-
 #include <stdio.h>
 #include <string.h>
 
@@ -67,7 +61,7 @@
 
 #include <openssl/err.h>
 
-#include "bn_lcl.h"
+#include "bn_local.h"
 
 /* TODO list
  *
@@ -283,6 +277,9 @@ BN_CTX_start(BN_CTX *ctx)
 void
 BN_CTX_end(BN_CTX *ctx)
 {
+	if (ctx == NULL)
+		return;
+
 	CTXDBG_ENTRY("BN_CTX_end", ctx);
 
 	if (ctx->err_stack)
@@ -468,7 +465,6 @@ BN_POOL_release(BN_POOL *p, unsigned int num)
 
 	p->used -= num;
 	while (num--) {
-		bn_check_top(p->current->vals + offset);
 		if (!offset) {
 			offset = BN_CTX_POOL_SIZE - 1;
 			p->current = p->current->prev;
